@@ -1,6 +1,6 @@
 /* xbfe -- a bitmap font editor for X11.
 
-Copyright (C) 1992 Free Software Foundation, Inc.
+Copyright (C) 1992, 2000 Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "config.h"
 
@@ -29,6 +29,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "font.h"
 #include "getopt.h"
 #include "Item.h"
+#include "logreport.h"
 #include "rand.h"
 
 #include "char.h"
